@@ -399,7 +399,7 @@ def delete_kernel(kernel_name: str, kernels_path: Path = Path.home().joinpath(".
         try:
             shutil.rmtree(env_path)
         except Exception as e:
-            _LOGGER.warning(f"Repo at {env_path.as_posix()} was not removed because of: {e}")
+            _LOGGER.debug(f"Repo at {env_path.as_posix()} was not removed because of: {e}")
 
     return command_output
 
@@ -497,6 +497,7 @@ def lock_dependencies_with_thoth(
         response = advise_using_config(
             pipfile=pipfile_string,
             pipfile_lock="",  # TODO: Provide Pipfile.lock retrieved?
+            runtime_environment_name=kernel_name,
             force=force,
             config=config,
             origin=origin,
@@ -534,7 +535,7 @@ def lock_dependencies_with_thoth(
                 advise = {"requirements": pipfile, "requirement_lock": pipfile_lock, "error": False}
 
     except Exception as api_error:
-        _LOGGER.warning(f"error locking dependencies using Thoth: {api_error}")
+        _LOGGER.debug(f"error locking dependencies using Thoth: {api_error}")
         advise["error"] = True
         if not advise.get("error_msg"):
             advise[
@@ -560,7 +561,7 @@ def lock_dependencies_with_thoth(
                 _LOGGER.info("Writing to Pipfile/Pipfile.lock in %r", env_path.as_posix())
                 project.to_files(pipfile_path=pipfile_path, pipfile_lock_path=pipfile_lock_path)
         except Exception as e:
-            _LOGGER.warning("Requirements files have not been stored successfully %r", e)
+            _LOGGER.debug("Requirements files have not been stored successfully %r", e)
 
     os.chdir(initial_path)
 
@@ -583,7 +584,7 @@ def get_thoth_config(
     config = _Configuration()
 
     if not config.config_file_exists():
-        _LOGGER.info("Thoth config does not exist, creating it...")
+        _LOGGER.debug("Thoth config does not exist, creating it...")
         try:
             config.create_default_config()
         except Exception as e:
@@ -642,7 +643,7 @@ def lock_dependencies_with_pipenv(
         try:
             subprocess.run("pip install pipenv", cwd=kernels_path, shell=True)
         except Exception as pipenv_install_error:
-            _LOGGER.warning("error installing pipenv: %r", pipenv_install_error)
+            _LOGGER.debug("error installing pipenv: %r", pipenv_install_error)
             result["error"] = True
             result["error_msg"] = pipenv_install_error
             returncode = 1
@@ -663,13 +664,13 @@ def lock_dependencies_with_pipenv(
             capture_output=True,
         )
     except Exception as pipenv_error:
-        _LOGGER.warning("error locking dependencies using Pipenv: %r", pipenv_error)
+        _LOGGER.debug("error locking dependencies using Pipenv: %r", pipenv_error)
         result["error"] = True
         result["error_msg"] = str(pipenv_error)
         returncode = 1
 
     if output.returncode != 0:
-        _LOGGER.warning("error in process trying to lock dependencies with pipenv: %r", output.stderr)
+        _LOGGER.debug("error in process trying to lock dependencies with pipenv: %r", output.stderr)
         result["error"] = True
         result["error_msg"] = str(output.stderr)
         returncode = 1
@@ -691,7 +692,7 @@ def lock_dependencies_with_pipenv(
             _LOGGER.debug(f"result from pipenv received: {result}")
 
         else:
-            _LOGGER.warning("Pipfile.lock cannot be found at: %r", str(pipfile_lock_path))
+            _LOGGER.debug("Pipfile.lock cannot be found at: %r", str(pipfile_lock_path))
             result["error"] = True
             result["error_msg"] = "Error retrieving Pipfile.lock created from pipenv."
 
@@ -885,7 +886,6 @@ def horus_lock_command(
     """Lock requirements in notebook metadata."""
     results = {}
     results["kernel_name"] = ""
-    results["runtime_environment"] = ""
     results["dependency_resolution_engine"] = resolution_engine
 
     notebook = get_notebook_content(notebook_path=path)
@@ -932,8 +932,9 @@ def horus_lock_command(
             _LOGGER.error(f"Could not get notebook content!: {e!r}")
             notebook_content_py = ""
 
-        runtime_environment = thoth_config.get_runtime_environment()
-
+        # runtime environment
+        runtime_environments = []
+        runtime_environment = dict(thoth_config.get_runtime_environment())
         runtime_environment["name"] = kernel
 
         operating_system = {
@@ -954,10 +955,13 @@ def horus_lock_command(
 
         runtime_environment["recommendation_type"] = recommendation_type
 
-        results["runtime_environment"] = runtime_environment
+        runtime_environments.append(runtime_environment)
 
         # Assign runtime environment to thoth config runtime environment.
-        thoth_config.set_runtime_environment(runtime_environment=runtime_environment, force=True)
+        thoth_config.content["runtime_environments"] = runtime_environments
+
+        # TODO: Use adjusted method from thamos
+        # thoth_config.set_runtime_environment(runtime_environment=runtime_environment, force=True)
 
         _, lock_results = lock_dependencies_with_thoth(
             kernel_name=kernel,
@@ -971,7 +975,7 @@ def horus_lock_command(
         if not lock_results["error"]:
             requirements = lock_results["requirements"]
             requirements_lock = lock_results["requirement_lock"]
-            notebook_metadata["thoth_config"] = json.dumps(thoth_config)
+            notebook_metadata["thoth_config"] = json.dumps(thoth_config.content)
 
         else:
             error = True
