@@ -144,6 +144,12 @@ class HorusMagics(Magics):
             help="Specify kernel name to be used when creating it.",
         )
 
+        # command: convert
+        _ = subparsers.add_parser(
+            "convert",
+            description="Convert notebook cells with pip commands to use horus commands.",
+        )
+
         # command: discover
         discover_command = subparsers.add_parser("discover", description="Discover dependencies from notebook content.")
         discover_command.add_argument("--force", help="Force saving dependencies in the notebook.", action="store_true")
@@ -166,6 +172,15 @@ class HorusMagics(Magics):
             "--use-overlay", help="Extract Pipfile and Pipfile.lock in overlay with kernel name.", action="store_true"
         )
 
+        is_jupyterhub = False
+
+        try:
+            nb_path = ipynbname.path()
+            nb_name = ipynbname.name()
+        except Exception as get_name_error:
+            is_jupyterhub = True
+            _LOGGER.debug(get_name_error)
+
         ## Parse inputs
         opts = line.split()
         args = parser.parse_args(opts)
@@ -179,12 +194,7 @@ class HorusMagics(Magics):
 
         _LOGGER.debug("Debug mode is on")
 
-        try:
-            nb_path = ipynbname.path()
-            nb_name = ipynbname.name()
-
-        except Exception as get_name_error:
-            _LOGGER.debug(get_name_error)
+        if is_jupyterhub:
             ## Jupyter Hub workaround
             _LOGGER.info("Use workaround for JupyterHub.")
 
@@ -199,13 +209,20 @@ class HorusMagics(Magics):
 
             # Check if file with name exists and retrieve it
             if file_path.exists():
+
+                # Take file stored.
                 with open(file_path) as json_file:
                     data = json.load(json_file)
 
                 nb_name = data["notebook_name"]
-                nb_path = os.getcwd() + f"/{nb_name}"
+                nb_path = os.getcwd() + f"/{str(nb_name)}"
+
             else:
-                raise Exception("Could not obtain notebook path from file. Please open issue with Thoth team!")
+                raise Exception(
+                    "Could not obtain notebook path from file. Please open issue in"
+                    " https://github.com/thoth-station/jupyterlab-requirements/issues/new?assignees"
+                    "=&labels=bug&template=bug_report.md!"
+                )
 
         _LOGGER.info(f"Notebook path: {nb_path}")
 
@@ -311,6 +328,9 @@ class HorusMagics(Magics):
 
             return console.print(table, justify="center")
 
+        if args.command == "clean":
+            _LOGGER.info("Cleaning notebook content to allow reproducibility...")
+
         if args.command == "lock":
             _LOGGER.info("Show dependencies content from notebook content.")
 
