@@ -25,14 +25,12 @@ import {
 import { Kernel } from '@jupyterlab/services';
 import { IMainMenu } from '@jupyterlab/mainmenu';
 import { ICommandPalette } from '@jupyterlab/apputils';
-import { Menu } from '@lumino/widgets';
 import { INotification } from "jupyterlab_toastify";
 
 // Customizations
 import { ManageDependenciesButtonExtension } from './dependencyManagementButton';
 import { KernelHandler } from './kernelHandlerMenu'
 import { Requirements, RequirementsLock } from "./types/requirements";
-import { ThothConfig } from "./types/thoth";
 import { get_kernel_name } from "./notebook";
 import { retrieve_config_file } from "./thoth";
 import { get_dependencies, store_notebook_name } from "./kernel";
@@ -90,6 +88,11 @@ async function activate(
         const session = sessionContext.session;
         let kernel = session.kernel;
 
+        var file_path = nbPanel.context.path
+        store_notebook_name(file_path).then(message => {
+          console.debug("storing file name", message)
+        })
+
         // Check to see if we found a kernel, and if its language is python.
         if (!(ThothPrivate.shouldUseKernel(kernel))) {
           console.debug("kernel approved: ", kernel.name.toString())
@@ -103,22 +106,37 @@ async function activate(
 
         console.log('loaded horus magic command extension');
 
-        // Use new message introduced in https://github.com/jupyterlab/jupyterlab/issues/10259
+        notebookTracker.activeCellChanged.connect(() => {
+
+          var track_change: boolean = false
+          notebookTracker.activeCell.editor.model.value.changed.connect(() => {
+            // user is typing
+            if (( notebookTracker.activeCell.editor.model.value.text == "!pip" ) || ( notebookTracker.activeCell.editor.model.value.text == "%pip" )) {
+              track_change = true
+              INotification.error("Manage dependencies: please do not use direct pip commands. Use horus and/or the UI plugin instead.");
+            }
+          })
+
+          if ( (notebookTracker.activeCell.editor.model.value.text.startsWith( "!pip" ) || notebookTracker.activeCell.editor.model.value.text.startsWith( "%pip" ) ) && ( track_change == false) ) {
+            INotification.error("Manage dependencies: please do not use direct pip commands. Use `%horus convert` to convert your cells.");
+          }
+
+        });
+
+        // Use new message introduced in https://github.com/jupyterlab/jupyterlab/pull/10493
         // NotebookActions.executionScheduled: Emitted when a notebook cell execution got scheduled/started.
-        NotebookActions.selectionExecuted.connect((sender, args) => {
-          const { lastCell } = args;
-          const cell = lastCell.model.value
+        NotebookActions.executionScheduled.connect((sender, args) => {
+          const { cell } = args;
 
-          if ( cell.text.startsWith( "%horus" ) ) {
-            var file_path = nbPanel.context.path
-
-            store_notebook_name(file_path).then(message => {
-              console.debug("storing file name", message)
+          // Do not allow users to run pip from notebook cells
+          if ( cell.editor.model.value.text.startsWith( "!pip" ) || cell.editor.model.value.text.startsWith( "%pip" ) ) {
+            nbPanel.sessionContext.session.kernel.interrupt().then( _ => {
+              INotification.error("Manage dependencies: please do not use direct pip commands. Use `%horus convert` to convert your cells.");
             })
           }
         })
 
-        // Use new message introduced in https://github.com/jupyterlab/jupyterlab/issues/10259
+        // Use new message introduced in https://github.com/jupyterlab/jupyterlab/pull/10493
         // NotebookActions.selectionExecuted: Emitted after all selected notebook cells completed execution successfully/unsuccessfully.
         NotebookActions.selectionExecuted.connect((sender, args) => {
           const { lastCell, notebook } = args;
@@ -139,8 +157,6 @@ async function activate(
                 let jsonObject: Requirements = JSON.parse(parsed_req);
                 notebook_metadata.set('requirements', JSON.stringify(jsonObject))
               }
-
-              nbPanel.context.save()
           }
 
           // Handle horus lock calls (lock + install and set-kernel)
@@ -166,8 +182,9 @@ async function activate(
                 notebook_metadata.set('dependency_resolution_engine', resolution_engine)
 
                 if ( resolution_engine == "thoth" ) {
-                  let thoth_config: Promise<ThothConfig> = retrieve_config_file(kernel_name)
-                  notebook_metadata.set('thoth_config', JSON.stringify(thoth_config))
+                  retrieve_config_file(kernel_name).then(thoth_config  => {
+                      notebook_metadata.set('thoth_config', JSON.stringify(thoth_config))
+                  })
                 }
 
                 get_dependencies(kernel_name).then(value => {
@@ -190,7 +207,6 @@ async function activate(
               }
             })
 
-            nbPanel.context.save()
           }
 
           // Handle horus set-kernel calls
@@ -224,7 +240,6 @@ async function activate(
               }
             })
 
-            nbPanel.context.save()
           }
 
           // Handle horus discover calls
@@ -253,7 +268,85 @@ async function activate(
               }
             }
 
-            nbPanel.context.save()
+          }
+
+          // Handle horus convert calls
+          if ( cell.text == "%horus convert" ) {
+
+            // Clean notebook content from cells that use !pip install
+            let number_of_cells = nbPanel.model.cells.length
+            var array = _.range(0, number_of_cells);
+
+            // Iterate over cells
+            let cells = notebook.model.cells
+
+            _.each(array, function (cell_number, key) {
+              let cell = notebook.model.cells.get(cell_number)
+              console.debug(cell)
+
+              if ( (cell.type === "code") && ( cell.value.text.startsWith( "!pip" ) || cell.value.text.startsWith( "%pip" )) ) {
+                  const cell_text = cell.value.text
+
+                  console.debug("cell n.", cell_number, cell_text);
+
+                  // Handle case with !pip | %pip install -r requirements.txt
+                  // Handle case with !pip | %pip install -r /folder/requirements.txt
+                  // Handle case with !pip | %pip install /path/to/my_package.whl
+                  // Handle case with !pip | %pip install git+https://github.com/...
+                  if ( cell.value.text.includes(".txt") || cell.value.text.includes(".git+https") || cell.value.text.includes(".whl") ) {
+                    var new_text = "#" + cell.value.text
+                  }
+                  else if ( cell.value.text.startsWith( "!pip install" ) || cell.value.text.startsWith( "%pip install" ) ) {
+
+                    // Handle case with !pip | %pip install <package name>
+                    // Handle case with !pip | %pip install <package name> <package name>
+                    // Handle case with !pip | %pip install <package name> <package name> <package name>
+
+                    const regex = /[!%]pip install ([a-zA-Z0-9_.-]*) ?([a-zA-Z0-9_.-]*) ?([a-zA-Z0-9_.-]*)/g;
+                    const found = cell_text.match(regex);
+                    console.debug(found)
+
+                    let commented_commands: Array<string> = []
+                    let packages: Array<string> = []
+
+                    _.each(found, function (match, key) {
+                      commented_commands.push(match)
+                      _.each(_.range(2, match.length), function (package_number, key) {
+
+                        const package_matched = match.split(" ")[package_number]
+                        console.debug(package_matched)
+                        packages.push(package_matched)
+                      })
+
+                    })
+
+                    // Remove ALL empty values ("", null, undefined and 0)
+                    packages = packages.filter(function(e){return e});
+                    var new_text = "#" + commented_commands.join("\n#") + "\n" + "%horus requirements --add " + packages.join(" ")
+
+                  }
+                  else {
+                    // Handle other cases with !pip | %pip (e.g. !pip freeze)
+                    var new_text = "#" + cell.value.text
+                  }
+
+                  console.debug("new cell text", new_text)
+
+                  // Instantiate a new empty cell
+                  const new_cell = nbPanel.model.contentFactory.createCell(
+                    cell.type,
+                    {}
+                  );
+
+                  new_cell.value.text = new_text;
+                  cells.remove(cell_number)
+                  cells.insert(cell_number, new_cell)
+              }
+
+            });
+
+            INotification.info("Manage dependencies: Notebook cells using pip have been converted to cells with %horus commands.");
+
           }
 
         });
@@ -264,8 +357,6 @@ async function activate(
           session.kernel.requestExecute({
             code
           })
-
-          nbPanel.context.save()
         })
 
       });
@@ -282,7 +373,7 @@ async function activate(
     }
 
     // Add button in main menu
-    const command = 'dependencies:kernel';
+    const command = commandIDs.kernelHandler;;
 
     function createPanel(): KernelHandler {
       const menu_extension = new KernelHandler();
@@ -291,8 +382,8 @@ async function activate(
 
     // Add a command
     commands.addCommand(command, {
-      label: 'Kernel delete...',
-      caption: 'Kernel delete...',
+      label: 'Delete Kernel...',
+      caption: 'Delete Kernel...',
       execute: (args: any) => {
         createPanel();
       }
@@ -306,14 +397,11 @@ async function activate(
       args: { origin: 'from the palette' }
     });
 
-    // Create a menu
-    // TODO: Move to Kernel Group menu
-    const tutorialMenu: Menu = new Menu({ commands });
-    tutorialMenu.title.label = 'Dependencies';
-    mainMenu.addMenu(tutorialMenu, { rank: 80 });
+    if ( mainMenu ) {
+      // Add command to Kernel Group
+      mainMenu.kernelMenu.addGroup( [{ command }], 30 )
+    }
 
-    // Add the command to the menu
-    tutorialMenu.addItem({ command, args: { origin: 'from the menu' } });
 };
 
 namespace ThothPrivate {
